#New ADVX macros
%define ADVXdir %{_datadir}/ADVX
%{expand:%(cat %{ADVXdir}/ADVX-build)}

%{expand:%%define apache_version %(rpm -q apache-devel|sed 's/apache-devel-\([0-9].*\)-.*$/\1/')}
%{expand:%%define apache_release %(rpm -q apache-devel|sed 's/apache-devel-[0-9].*-\(.*\)$/\1/')}

%{expand:%%define mm_major %(mm-config --version|sed 's/MM \([0-9]\)\.\([0-9.].*\) \(.*\)$/\1/')}
%{expand:%%define mm_minor %(mm-config --version|sed 's/MM \([0-9]\)\.\([0-9.].*\) \(.*\)$/\2/')}
%define mm_version %{mm_major}.%{mm_minor}

%define version 1.6.0
%define release 14mdk
%define name auth_ldap
%define real_name mod_auth_ldap
%define openldap_version 2.1.22

Summary:	This is a LDAP authentication module for Apache
Name:		%{name}
Group:		System/Servers
License:	GPL
Version:	%{version}
Release: 	%{release}
Source:		http://www.rudedog.org/auth_ldap/auth_ldap-%{version}.tar.bz2
Patch:		auth_ldap_register.patch.bz2
URL:		http://www.rudedog.org/auth_ldap/
Prefix:		%{_prefix}
BuildRoot:	%{_tmppath}/%{name}-%{version}-root

%description
This is an authentication module for Apache that allows you to authenticate
HTTP clients using user entries in an LDAP directory.

%package -n %{real_name}
Summary:        This is a LDAP authentication module for Apache
Group:          System/Servers
Obsoletes:      auth_ldap
Provides:       auth_ldap = %{version}-%{release}

Prereq: apache = %{apache_version}
Prereq:	apache-common >= %{apache_version}
Prereq:	apache-conf >= %{apache_version}
Prereq: mm = %{mm_major}.%{mm_minor}

BuildRequires: ADVX-build >= 1.2
BuildRequires:  openldap-devel
BuildRequires:  apache-devel
BuildRequires:  libdb3.3-devel
Provides: 	ADVXpackage
Provides:	AP13package

%description -n %{real_name}
This is an authentication module for Apache that allows you to authenticate
HTTP clients using user entries in an LDAP directory.

%prep
%setup -q -n %{name}-%{version}
%patch -p1

%build
%configure --with-ldap-sdk=openldap --with-shared-cache \
	--with-apxs=%{_sbindir}/apxs --with-frontpage
make

%install

rm -rf %{buildroot}
mkdir -p %{buildroot}%{_libdir}/apache-extramodules

install -m755 auth_ldap.so  %{buildroot}%{_libdir}/apache-extramodules/auth_ldap.so

# Doc installation
mkdir -p %{buildroot}%{_docdir}/%{real_name}-%{version}
cp *.html *.xml *.xsl *.dtd PROBLEMS %{buildroot}%{_docdir}/%{real_name}-%{version}

# Doc linking
mkdir -p %{buildroot}%{ap_webdoc}
pushd %{buildroot}%{ap_webdoc}
ln -s ../../../..%{_docdir}/%{real_name}-%{version} %{real_name}
popd

%pre
#Check config file sanity
%AP13pre

%post -n %{real_name}
if [ $1 = "1" ]; then
   #We're in Install mode, add module to the config files
   for config in %{ap_base}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxaddmod -a -e $config ]; then
        %{_sbindir}/advxaddmod $config \
         extramodules/auth_ldap.so auth_ldap.c auth_ldap_module \
         define=HAVE_AUTH_LDAP
     fi
   done
   %ADVXpost
fi 

if [ $1 -gt 1 ]; then
   #We're in *upgrade mode*. Since we can't be sure the configuration files
   #are sane, remove module from the conf files to clean them, re-add again 
   #in a way that the older module we're replacing won't try to erase (the 
   #post scripts were broken on some packages), and finally clean the module
   #specific config file so it's compatible with the upgrade.
   for config in %{ap_base}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxdelmod -a -e $config ]; then
        %{_sbindir}/advxdelmod $config \
         extramodules/auth_ldap.so auth_ldap.c auth_ldap_module \
         define=HAVE_AUTH_LDAP
     fi
     if [ -x %{_sbindir}/advxaddmod -a -e $config ]; then
        %{_sbindir}/advxaddmod $config \
         extramodules/auth_ldap.so auth_ldap.c auth_ldap_module \
         define=HAVE_AUTH_LDAP
     fi
   done
   %ADVXpost
fi

%postun -n %{real_name}
if [ $1 = "0" ]; then
   for config in %{ap_base}/conf/{httpd,httpd-perl}.conf; do
     if [ -x %{_sbindir}/advxdelmod -a -e $config ]; then
        %{_sbindir}/advxdelmod $config \
         extramodules/auth_ldap.so auth_ldap.c auth_ldap_module \
         define=HAVE_AUTH_LDAP
     fi
   done
   %ADVXpost
fi
					  
%clean
rm -rf %{buildroot}

%files -n %{real_name}
%defattr(-,root,root)
%{_libdir}/apache-extramodules/auth_ldap.so
%dir %{_docdir}/%{real_name}-%{version}
%doc %{_docdir}/%{real_name}-%{version}/*
%{ap_webdoc}/*

%changelog
* Tue Mar 02 2004 Olivier Thauvin <thauvin@aerov.jussieu.fr> 1.6.0-14mdk
- Fix dependencies && rebuild

* Tue Sep 16 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-13mdk
- rebuild with apache 1.3.28

* Fri Aug 08 2003 Buchan Milne <bgmilne@linux-mandrake.com> 1.6.0-12mdk
- Rebuild to lose libsasl7 dependency

* Fri Feb 28 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-11mdk
- add BuildRequires libdb3.3-devel

* Thu Feb 13 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-10mdk
- new macros from ADVX-build

* Mon Jan 06 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-9mdk
- rebuilt with new openssl

* Mon Jan 06 2003 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-8mdk
- rebuilt for new mm version
- Add Provides: ADVXpackage, all ADVX package will have this tag, 
  so we can easily do a rpm --whatprovides ADVXpackage to find out
  what ADVX packages a user has installed on his system. 

* Tue Jul  9 2002 Pixel <pixel@mandrakesoft.com> 1.6.0-7mdk
- Apache 1.3.26
- rebuild (so that it builds with "-D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64")
  => fix segfault

* Mon Apr 15 2002 Christian Belisle <cbelisle@mandrakesoft.com> 1.6.0-6mdk
- Apache 1.3.24.

* Mon Mar 04 2002 Jean-Michel Dault <jmdault@mandrakesoft.com> 1.6.0-5mdk
- Registered module so we know when it's loaded

* Wed Feb 06 2002 Christian Belisle <cbelisle@mandrakesoft.com> 1.6.0-4mdk
- Keep the same SRPMS name and change RPMS name.

* Wed Feb 06 2002 Christian Belisle <cbelisle@mandrakesoft.com> 1.6.0-3mdk
- Spec cleanup.
- post and postun follow the advx apache's modules standard.
- Build with FrontPage hack (see doc for more info).

* Thu Oct 18 2001 Philippe Libat <philippe@mandrakesoft.com> 1.6.0-2mdk
- new db3

* Fri Aug 24 2001 Philippe Libat <philippe@mandrakesoft.com> 1.6.0-1mdk
- new version

* Thu May 31 2001 Philippe Libat <philippe@mandrakesoft.com> 1.5.4-1mdk
- new version

* Wed May 16 2001 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.4.7-2mdk
- Rebuild.

* Wed Dec 13 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.4.7-1mdk
- new and shiny source to fix a not-so-new-and-shiny source.

* Mon Nov 13 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 1.4.5-1mdk
- new and shiny version.
- _libdir macro.

* Wed Aug 30 2000 Etienne Faure <etienne@mandrakesoft.com> 1.4.0-5mdk
- rebuilt with new %doc macro

* Sat May 13 2000 David BAUDENS <baudens@mandrakesoft.com> 1.4.0-4mdk
- Fix build for i486

* Tue Mar 21 2000 Jerome Dumonteil <jd@mandrakesoft.com>
- build for mandrake 7.1

* Tue Nov 30 1999 Jerome Dumonteil <jd@mandrakesoft.com>
- use of _tmppath for BuildRoot

* Tue Nov  2 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- First mandrake release.

* Tue Sep 07 1999 Cristian Gafton <gafton@redhat.com>
- first build for Red Hat Linux 6.1
